Database

Struct Database 

pub struct Database { /* private fields */ }
The ruby-advisory-db database.

Implementations

Source

impl Database

pub fn open(path: &Path) -> Result<Self, DatabaseError>

Open an existing advisory database at the given path.

pub fn default_path() -> PathBuf

The default database path: ~/.local/share/ruby-advisory-db.

Can be overridden by GEM_AUDIT_DB environment variable.

pub fn download(path: &Path, _quiet: bool) -> Result<Self, DatabaseError>

Download the ruby-advisory-db to the given path.

pub fn update(&self) -> Result<bool, DatabaseError>

Update the database by fetching from origin and fast-forwarding.

If the git fetch fails (e.g. due to ref-update issues in containerised environments), falls back to a fresh clone so the update always succeeds.

pub fn is_git(&self) -> bool

Check whether the database path is a git repository.

pub fn exists(&self) -> bool

Check whether the database exists and is non-empty.

pub fn path(&self) -> &Path

The path to the database.

pub fn commit_id(&self) -> Option<String>

The last commit ID (HEAD) of the database repository.

pub fn last_updated_at(&self) -> Option<i64>

The timestamp of the last commit.

pub fn advisories(&self) -> Vec<Advisory>

Enumerate all advisories in the database.

pub fn advisories_for(&self, gem_name: &str) -> Vec<Advisory>

Get advisories for a specific gem.

pub fn check_gem( &self, gem_name: &str, version: &Version, ) -> (Vec<Advisory>, usize)

Check a gem (name + version) against the database.

Returns all advisories that the gem version is vulnerable to, along with the count of advisory files that failed to load.

pub fn advisories_for_ruby(&self, engine: &str) -> Vec<Advisory>

Get advisories for a specific Ruby engine (e.g., “ruby”, “jruby”).

pub fn check_ruby( &self, engine: &str, version: &Version, ) -> (Vec<Advisory>, usize)

Check a Ruby engine+version against the database.

Returns all advisories that the Ruby version is vulnerable to, along with the count of advisory files that failed to load.

pub fn size(&self) -> usize

Total number of gem advisories in the database.

pub fn rubies_size(&self) -> usize

Total number of Ruby interpreter advisories in the database.